@@ -1,8 +1,5 @@
 package Log::Log4perl::Tiny;
-{
-  $Log::Log4perl::Tiny::VERSION = '1.2.7';
-}
-
+$Log::Log4perl::Tiny::VERSION = '1.2.9';
 # ABSTRACT: mimic Log::Log4perl in one single module
 
 use warnings;
@@ -179,6 +176,17 @@ sub build_channels {
 
 sub get_logger { return $_instance ||= __PACKAGE__->new(); }
 sub LOGLEVEL { return get_logger()->level(@_); }
+sub LEVELID_FOR {
+   my $level = shift;
+   return $id_for{$level} if exists $id_for{$level};
+   return;
+}
+sub LEVELNAME_FOR {
+   my $id = shift;
+   return $name_of{$id} if exists $name_of{$id};
+   return $id if exists $id_for{$id};
+   return;
+}
 
 sub format {
    my $self = shift;
@@ -567,64 +575,7 @@ Log::Log4perl::Tiny - mimic Log::Log4perl in one single module
 
 =head1 VERSION
 
-version 1.2.7
-
-=head1 SYNOPSIS
-
-   use Log::Log4perl::Tiny qw( :easy );
-   Log::Log4perl->easy_init({
-      file   => '/var/log/something.log',
-      layout => '[%d] [%-5P:%-5p] %m%n',
-      level  => $INFO,
-   });
-
-   WARN 'something weird happened';
-   INFO 'just doing it';
-   DEBUG 'this does not get printed at $INFO level';
-
-   # LOGLEVEL isn't in Log::Log4perl, but might come handy
-   LOGLEVEL($DEBUG);   # enable debugging for small section
-   # otherwise, "get_logger()->level($DEBUG)", see below
-
-   DEBUG 'now this gets printed';
-   LOGLEVEL($INFO);    # disable debugging again
-   DEBUG 'skipped, again';
-   DEBUG 'complex evaluation value:', sub { 
-      # evaluation skipped if log level filters DEBUG out
-   };
-
-   # Object-oriented interface is available as well
-   my $logger = get_logger();
-   $logger->level($DEBUG);   # enable debugging for small section
-   $logger->debug('whatever you want');
-   $logger->level($INFO);    # disable debugging again
-
-   # All stealth loggers are available
-   LOGCONFESS 'I cannot accept this, for a whole stack of reasons!';
-
-   # Want to change layout?
-   $logger->layout('[%d %p] %m%n');
-   # or, equivalently
-   $logger->format('[%d %p] %m%n');
-
-   # Want to send the output somewhere else?
-   use IO::Handle;
-   open my $fh, '>>', '/path/to/new.log';
-   $fh->autoflush();
-   $logger->fh($fh);
-
-   # Want to multiplex output to different channels?
-   $logger->fh(
-      build_channels(
-         fh          => \*STDERR,
-         file_create => '/var/log/lastrun.log',
-         file_append => '/var/log/overall.log',
-      )
-   );
-
-   # Want to handle the output message by yourself?
-   my @queue; # e.g. all log messages will be put here
-   $logger->fh(sub { push @queue, $_[0] });
+version 1.2.9
 
 =head1 DESCRIPTION
 
@@ -885,7 +836,7 @@ in line with L<Log::Log4perl>):
 
 =item C<< ALWAYS >>
 
-emit log whatever the configured logging level, apart from C<$OFF> that
+emit log whatever the configured logging level, apart from C<$DEAD> that
 disables all logging;
 
 =item C<< LOGWARN >>
@@ -988,6 +939,63 @@ is fixed. (Thanks to C<Log::Tiny> for the cool trick of how to handle
 the C<printf>-like string, which is probably mutuated from
 C<Log::Log4perl> itself according to the comments).
 
+=head1 SYNOPSYS
+
+   use Log::Log4perl::Tiny qw( :easy );
+   Log::Log4perl->easy_init({
+      file   => '/var/log/something.log',
+      layout => '[%d] [%-5P:%-5p] %m%n',
+      level  => $INFO,
+   });
+
+   WARN 'something weird happened';
+   INFO 'just doing it';
+   DEBUG 'this does not get printed at $INFO level';
+
+   # LOGLEVEL isn't in Log::Log4perl, but might come handy
+   LOGLEVEL($DEBUG);   # enable debugging for small section
+   # otherwise, "get_logger()->level($DEBUG)", see below
+
+   DEBUG 'now this gets printed';
+   LOGLEVEL($INFO);    # disable debugging again
+   DEBUG 'skipped, again';
+   DEBUG 'complex evaluation value:', sub { 
+      # evaluation skipped if log level filters DEBUG out
+   };
+
+   # Object-oriented interface is available as well
+   my $logger = get_logger();
+   $logger->level($DEBUG);   # enable debugging for small section
+   $logger->debug('whatever you want');
+   $logger->level($INFO);    # disable debugging again
+
+   # All stealth loggers are available
+   LOGCONFESS 'I cannot accept this, for a whole stack of reasons!';
+
+   # Want to change layout?
+   $logger->layout('[%d %p] %m%n');
+   # or, equivalently
+   $logger->format('[%d %p] %m%n');
+
+   # Want to send the output somewhere else?
+   use IO::Handle;
+   open my $fh, '>>', '/path/to/new.log';
+   $fh->autoflush();
+   $logger->fh($fh);
+
+   # Want to multiplex output to different channels?
+   $logger->fh(
+      build_channels(
+         fh          => \*STDERR,
+         file_create => '/var/log/lastrun.log',
+         file_append => '/var/log/overall.log',
+      )
+   );
+
+   # Want to handle the output message by yourself?
+   my @queue; # e.g. all log messages will be put here
+   $logger->fh(sub { push @queue, $_[0] });
+
 =head1 INTERFACE 
 
 You have two interfaces at your disposal, the functional one (with all
@@ -998,7 +1006,7 @@ explicit actions upon a logger object). Choose your preferred option.
 
 The functional interface sports the following functions (imported
 automatically when C<:easy> is passed as import option except for
-C<LOGLEVEL>):
+C<LEVELID_FOR>, C<LEVELNAME_FOR> and C<LOGLEVEL>):
 
 =over
 
@@ -1020,6 +1028,19 @@ stealth logger functions, each emits a log at the corresponding level;
 
 emit log whatever the configured logging level (except C<$DEAD>);
 
+=item C<< LEVELID_FOR >>
+
+returns the identifier related to a certain level. The input level can be
+either a name or an identifier itself. Returns C<undef> if it is neither.
+
+It can be used e.g. if you want to use L</log> but you only have the level
+name, not its identifier;
+
+=item C<< LEVELNAME_FOR >>
+
+returns the name related to a certain level. The input level can be either
+a name or an identifier itself. Returns C<undef> if it is neither.
+
 =item C<< LOGWARN >>
 
 emit log at C<WARN> level and then C<warn()> it;
@@ -1353,7 +1374,7 @@ Flavio Poletti <polettix@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2013 by Flavio Poletti <polettix@cpan.org>.
+Copyright (C) 2010-2016 by Flavio Poletti <polettix@cpan.org>.
 
 This module is free software.  You can redistribute it and/or
 modify it under the terms of the Artistic License 2.0.
